@@ -30,7 +30,7 @@ function (tr,
                             pr.birch.ba = birch,
                             pr.other.ba = other )
                        )
-    recr.ha[, "ustandID"] <- fl$ustandID
+    recr.ha[, "plot.id"] <- fl$plot.id
     recr.ha[, "tree2ha"]  <- fl[["tree2ha"]]
     recr.ha[, "subplot.size.m2"] <- fl[["subplot.size.m2"]]
     
@@ -63,7 +63,7 @@ function (tr,
     }
     n.newtrees <- colSums(recr.ha[, paste(all.spp, ".e", sep = "")])
 
-    uid <-  rep.int(recr.ha[, "ustandID"], length(all.spp))
+    uid <-  rep.int(recr.ha[, "plot.id"], length(all.spp))
     reps <- recr.ha[, paste(all.spp, ".e", sep = "")]
   reps <- unlist(reps)
   
@@ -73,7 +73,7 @@ function (tr,
   
 
   return(
-    list(ustandID = if (noingrowth) NULL else rep.int(uid, reps),
+    list(plot.id = if (noingrowth) NULL else rep.int(uid, reps),
          treeid    = treeid,
          dbh.mm    = foo2(rep(50, sum(n.newtrees)), next.period),
          height.dm = foo2(rep(120, sum(n.newtrees)), next.period),
